pub enum RuleSetting {
Simple(RuleEnforcement),
Custom([(RuleEnforcement, BTreeMap<String, Value>); 1]),
}Expand description
The settings for an individual rule. Can be a single value such as warn or error, or an array with the rule enforcement value as the first value, and the rule-specific settings in an object right after that. (example: [“allow”, { “setting1”: true }])
Variants
Simple(RuleEnforcement)
Custom([(RuleEnforcement, BTreeMap<String, Value>); 1])